/* -*- Mode: IDL; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface txIFunctionEvaluationContext;
interface txINodeSet;

[scriptable, uuid(c180e993-aced-4839-95a0-ecd5ff138be9)]
interface txIEXSLTRegExFunctions : nsISupports
{
    txINodeSet match(in txIFunctionEvaluationContext aContext,
                     in DOMString aString, in DOMString aRegEx,
                     in DOMString aFlags);
    DOMString replace(in DOMString aString, in DOMString aRegEx,
                      in DOMString aFlags, in DOMString aReplace);
    boolean test(in DOMString aString, in DOMString aRegEx,
                 in DOMString aFlags);
};
