/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef nsTextServicesCID_h__
#define nsTextServicesCID_h__

#define NS_TEXTSERVICESDOCUMENTINTERNAL_CID     \
{ /* 019718E2-CDB5-11d2-8D3C-000000000000 */    \
0x019718e2, 0xcdb5, 0x11d2,                     \
{ 0x8d, 0x3c, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0 } }

#define NS_TEXTSERVICESDOCUMENT_CID             \
{ /* 019718E3-CDB5-11d2-8D3C-000000000000 */    \
0x019718e3, 0xcdb5, 0x11d2,                     \
{ 0x8d, 0x3c, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0 } }

#endif /* nsTextServicesCID_h__ */
