/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set ts=2 et sw=2 tw=80: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef mozilla_dom_CPOWManagerGetter_h
#define mozilla_dom_CPOWManagerGetter_h

namespace mozilla {

namespace jsipc {
class JavaScriptShared;
} /* namespace jsipc */

namespace dom {
class CPOWManagerGetter
{
public:
  virtual mozilla::jsipc::JavaScriptShared* GetCPOWManager() = 0;
};
} /* namespace dom */

} /* namespace mozilla */

#endif /* mozilla_dom_CPOWManagerGetter_h */
