/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

/*
 * The nsPIEditorTransaction interface.
 * <P>
 * This interface is implemented by every transaction created by this
 * editor implementation. It is used to help us distinguish our internal
 * transactions from those generated by 3rd party extensions.
 */
[scriptable, uuid(4f18ada2-0ddc-11d5-9d3a-0060b0f8baff)]
interface nsPIEditorTransaction : nsISupports
{
  readonly attribute DOMString txnDescription;
};

