/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM ../../../dist/idl/nsITabChild.idl
 */

#ifndef __gen_nsITabChild_h__
#define __gen_nsITabChild_h__


#ifndef __gen_domstubs_h__
#include "domstubs.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIContentFrameMessageManager; /* forward declaration */

class nsIWebBrowserChrome3; /* forward declaration */


/* starting interface:    nsITabChild */
#define NS_ITABCHILD_IID_STR "2eb3bc54-78bf-40f2-b301-a5b5b70f7da0"

#define NS_ITABCHILD_IID \
  {0x2eb3bc54, 0x78bf, 0x40f2, \
    { 0xb3, 0x01, 0xa5, 0xb5, 0xb7, 0x0f, 0x7d, 0xa0 }}

class NS_NO_VTABLE nsITabChild : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_ITABCHILD_IID)

  /* readonly attribute nsIContentFrameMessageManager messageManager; */
  NS_IMETHOD GetMessageManager(nsIContentFrameMessageManager * *aMessageManager) = 0;

  /* attribute nsIWebBrowserChrome3 webBrowserChrome; */
  NS_IMETHOD GetWebBrowserChrome(nsIWebBrowserChrome3 * *aWebBrowserChrome) = 0;
  NS_IMETHOD SetWebBrowserChrome(nsIWebBrowserChrome3 *aWebBrowserChrome) = 0;

  /* [notxpcom] void sendRequestFocus (in boolean canFocus); */
  NS_IMETHOD_(void) SendRequestFocus(bool canFocus) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsITabChild, NS_ITABCHILD_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSITABCHILD \
  NS_IMETHOD GetMessageManager(nsIContentFrameMessageManager * *aMessageManager) MOZ_OVERRIDE; \
  NS_IMETHOD GetWebBrowserChrome(nsIWebBrowserChrome3 * *aWebBrowserChrome) MOZ_OVERRIDE; \
  NS_IMETHOD SetWebBrowserChrome(nsIWebBrowserChrome3 *aWebBrowserChrome) MOZ_OVERRIDE; \
  NS_IMETHOD_(void) SendRequestFocus(bool canFocus) MOZ_OVERRIDE; 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSITABCHILD(_to) \
  NS_IMETHOD GetMessageManager(nsIContentFrameMessageManager * *aMessageManager) MOZ_OVERRIDE { return _to GetMessageManager(aMessageManager); } \
  NS_IMETHOD GetWebBrowserChrome(nsIWebBrowserChrome3 * *aWebBrowserChrome) MOZ_OVERRIDE { return _to GetWebBrowserChrome(aWebBrowserChrome); } \
  NS_IMETHOD SetWebBrowserChrome(nsIWebBrowserChrome3 *aWebBrowserChrome) MOZ_OVERRIDE { return _to SetWebBrowserChrome(aWebBrowserChrome); } \
  NS_IMETHOD_(void) SendRequestFocus(bool canFocus) MOZ_OVERRIDE { return _to SendRequestFocus(canFocus); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSITABCHILD(_to) \
  NS_IMETHOD GetMessageManager(nsIContentFrameMessageManager * *aMessageManager) MOZ_OVERRIDE { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMessageManager(aMessageManager); } \
  NS_IMETHOD GetWebBrowserChrome(nsIWebBrowserChrome3 * *aWebBrowserChrome) MOZ_OVERRIDE { return !_to ? NS_ERROR_NULL_POINTER : _to->GetWebBrowserChrome(aWebBrowserChrome); } \
  NS_IMETHOD SetWebBrowserChrome(nsIWebBrowserChrome3 *aWebBrowserChrome) MOZ_OVERRIDE { return !_to ? NS_ERROR_NULL_POINTER : _to->SetWebBrowserChrome(aWebBrowserChrome); } \
  NS_IMETHOD_(void) SendRequestFocus(bool canFocus) MOZ_OVERRIDE; 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsTabChild : public nsITabChild
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSITABCHILD

  nsTabChild();

private:
  ~nsTabChild();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS(nsTabChild, nsITabChild)

nsTabChild::nsTabChild()
{
  /* member initializers and constructor code */
}

nsTabChild::~nsTabChild()
{
  /* destructor code */
}

/* readonly attribute nsIContentFrameMessageManager messageManager; */
NS_IMETHODIMP nsTabChild::GetMessageManager(nsIContentFrameMessageManager * *aMessageManager)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute nsIWebBrowserChrome3 webBrowserChrome; */
NS_IMETHODIMP nsTabChild::GetWebBrowserChrome(nsIWebBrowserChrome3 * *aWebBrowserChrome)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsTabChild::SetWebBrowserChrome(nsIWebBrowserChrome3 *aWebBrowserChrome)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [notxpcom] void sendRequestFocus (in boolean canFocus); */
NS_IMETHODIMP_(void) nsTabChild::SendRequestFocus(bool canFocus)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsITabChild_h__ */
